/*
 * crash-manager
 *
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __CRASH_MANAGER_H__
#define __CRASH_MANAGER_H__

#include <sys/types.h>
#include <unistd.h>
#include <stdbool.h>

/* Paths and variables */
struct crash_info {
	bool livedump;
	bool kill;
	bool print_result_path;
	pid_t pid_info;
	pid_t tid_info;
	int uid_info;
	int gid_info;
	int sig_info;
	int prstatus_fd;
	char *cmd_line;
	char *cmd_path;
	char *temp_dir;
	char *name;
	char *app_root_path;
	char *result_path;
	char *pfx;
	char *info_path;
	char *core_path;
	char *log_path;
	char *zip_path;
	char *output_path;
	char *executable_path;
	char *appid;
	char *pkgid;
	time_t time_info;
	int lock_fd;
};

bool crash_manager_direct(struct crash_info *cinfo);
bool crash_manager_livedump_pid(pid_t pid, const char *dump_reason, char *report_path, size_t report_path_len);
void crash_info_init(struct crash_info *cinfo);
void crash_manager_free(struct crash_info *cinfo);

bool have_livecoredumper(void);
#endif
